@@ -1,5 +1,5 @@
 package List::Objects::WithUtils::Role::Hash;
-$List::Objects::WithUtils::Role::Hash::VERSION = '2.023002';
+$List::Objects::WithUtils::Role::Hash::VERSION = '2.024001';
 use strictures 2;
 
 use Module::Runtime ();
@@ -38,10 +38,8 @@ sub type { }
 our %Required;
 sub new {
   my $arraytype = $_[0]->array_type;
-  unless (exists $Required{$arraytype}) {
-    Module::Runtime::require_module($arraytype);
-    $Required{$arraytype} = 1
-  }
+  $Required{$arraytype} = Module::Runtime::require_module($arraytype)
+    unless exists $Required{$arraytype};
   bless +{ @_[1 .. $#_] }, Scalar::Util::blessed($_[0]) || $_[0]
 }
 
@@ -117,14 +115,11 @@ sub sliced {
 
 sub set {
   my $self = shift;
-
   my (@keysidx, @valsidx);
   for (0 .. $#_) {
     $_ % 2 ? push @valsidx, $_ : push @keysidx, $_
   }
-
   @{$self}{ @_[@keysidx] } = @_[@valsidx];
-
   $self
 }
 
@@ -321,7 +316,9 @@ Returns boolean true if the key exists.
 
   my %hash = $hash->export;
 
-Returns a raw key/value list.
+Returns a raw key => value list.
+
+For a plain HASH-type reference, see: L</unbless>
 
 =head3 array_type
 
@@ -392,13 +389,13 @@ Returns a plain C<HASH> reference (shallow clone).
 
 Clears the current hash entirely.
 
-Returns the hash object.
+Returns the (same, but now empty) hash object.
 
 =head3 delete
 
-  $hash->delete( @keys );
+  $hash->delete(@keys);
 
-Deletes the given keys from the hash.
+Deletes the given key(s) from the hash.
 
 Returns an L</array_type> object containing the deleted values.
 
@@ -421,7 +418,7 @@ Returns the current hash object.
 
 Like L</set>, but only sets values that do not already exist in the hash.
 
-Returns the hash object.
+Returns the current hash object.
 
 =head2 Methods that retrieve items
 
@@ -439,12 +436,12 @@ hash.)
 =head3 get_path
 
   my $hash = hash(
-    foo  => +{ bar => +{ baz => 1 } },
+    foo  => +{ bar => +{ baz => 'bork'  } },
     quux => [ +{ weeble => 'snork' } ],
   );
-  my $item = $hash->get_path(qw/foo bar baz/);        # 1
+  my $item = $hash->get_path(qw/foo bar baz/);  # 'bork'
 
-Attempt to retrieve a scalar item from a 'deep' hash (without risking
+Attempt to retrieve a value from a 'deep' hash (without risking
 autovivification).
 
 If an element of the given path is a (plain) array reference, as in this
